@@ -130,6 +130,14 @@ def test__version__ordering() -> None:
     assert Version("0.1.0") != Version("0.1.0", dirty=True)
     assert Version("0.1.0") != Version("0.1.0", dirty=False)
 
+    assert Version("0.2.0") < Version("0.2.1")
+    assert Version("1.1.0") < Version("1.2.0")
+    assert Version("1.0.0", stage=("rc", 1)) < Version("1.0.0")
+    assert Version("1.0.0", stage=("a", 1)) < Version("1.0.0", stage=("b", 1))
+    assert Version("1.0.0") < Version("1.0.0", stage=("post", 1))
+    assert Version("1.0.0", epoch=1) < Version("1.0.0", epoch=2)
+    assert Version("1.0.0", stage=("bar", 1)) < Version("1.0.0", stage=("foo", 1))
+
 
 def test__version__serialize__pep440() -> None:
     assert Version("0.1.0").serialize() == "0.1.0"
@@ -150,6 +158,10 @@ def test__version__serialize__pep440() -> None:
     assert Version("1", stage=("a", 0), distance=3, commit="abc", dirty=False).serialize() == "1a0.post3.dev0+abc"
     assert Version("1", stage=("a", 2), distance=0, commit="abc", dirty=False).serialize() == "1a2"
     assert Version("1", stage=("a", 2), distance=3, commit="000", dirty=False).serialize() == "1a2.post3.dev0+000"
+    assert (
+        Version("1", stage=("a", 0), distance=3, commit="abc", dirty=False).serialize(commit_prefix="x")
+        == "1a0.post3.dev0+xabc"
+    )
 
     assert Version("1", stage=("a", None)).serialize() == "1a0"
     assert Version("1", stage=("b", 2)).serialize() == "1b2"
@@ -396,6 +408,9 @@ def test__version__serialize__format_as_str() -> None:
     with pytest.raises(ValueError):
         Version("0.1.0").serialize(format="v{base}", style=Style.Pep440)
 
+    assert Version("1", commit="abc").serialize(format="{commit}", commit_prefix="x") == "xabc"
+    assert Version("1", branch="a/b").serialize(format="{branch_escaped}", escape_with=".") == "a.b"
+
 
 def test__version__serialize__format_as_callable() -> None:
     def format(v: Version) -> str:
